<?php

namespace App\Http\Controllers;

use App\Models\Event;
use Illuminate\Http\Request;

class EventController extends Controller
{
    //

    public function index()
    {
        $events = Event::where('status',1)->orderBy('id','desc')->paginate(6);
        return view('events', compact('events'));
    }

    public function create()
    {
        return view('admin.event'); 
    }

    public function save(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'file' => 'required',
            'file' => 'mimes:jpeg,jpg,png|max:2048',
            'date' => 'required',
            'time' => 'required',
            'location' => 'required',
            'description' => 'required'
        ]);

        $image_path = '';
        
        $path = 'images/gallery';
        if ($request->hasfile('file')) {
            $file = $request->file('file');
            $imageName = 'event_'.time().rand(1,1000).'.'.$file->extension();
            if ($file->move($path, $imageName)) {
                $image_path = $path.'/'.$imageName;
            }
        }

        $result = Event::create([
            'name' => $request->title,
            'image_path' => $image_path,
            'date' => $request->date,
            'time' => $request->time,
            'location' => $request->location,
            'remarks' => $request->description,
        ]);

        if ($result) {
            return redirect()->route('eventList')->with('message', 'Success! Event Created');
        }

        else {
            return back()->with('error', 'Alert! Event not create');
        }

    }

    public function list()
    {
        $events = Event::orderBy('id','desc')->get();
        return view('admin.eventList', compact('events'));
    }

    public function delete($id)
    {
        $event = Event::find($id);

        if(file_exists(public_path($event->image_path)))
        {
            unlink($event->image_path);
        }

        $result = $event->delete();
        if($result)
        {
            return back()->with('message', 'Event Delete');
        }
        return back()->with('error', 'Alert! Error');
    }

    public function edit($id)
    {
        $event = Event::find($id);
        return view('admin.editEvent', compact('event'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'title' => 'required',
            'file' => 'required',
            'file' => 'mimes:jpeg,jpg,png|max:2048',
            'date' => 'required',
            'time' => 'required',
            'location' => 'required',
            'description' => 'required'
        ]);

        $event = Event::find($id);

        $image_path = '';
        
        $path = 'images/gallery';
        if ($request->hasfile('file')) {
            $file = $request->file('file');
            $imageName = 'event_'.time().rand(1,1000).'.'.$file->extension();
            if ($file->move($path, $imageName)) {
                $event->image_path = $path.'/'.$imageName;
            }
        }

        $event->name = $request->title;
        $event->date = $request->date;
        $event->time = $request->time;
        $event->location = $request->location;
        $event->remarks = $request->description;
        $result = $event->save();
        if($result)
        {
            return redirect()->route('eventList')->with('message', 'Event Update');
        }
    }

    public function eventStatus($id)
    {
        $new = 1;
        $event = Event::find($id);
        $current =  $event->status;
        if($current == 1) {
            $new = 0;
        }
        $event->status = $new;
        $event->save();

        return back()->with('message', 'Event status update');
    }
}
