<?php

namespace App\Http\Controllers;

use App\Models\Event;
use App\Models\Gallery;
use App\Models\Volunteer;
use App\Models\UserContact;
use Illuminate\Http\Request;

class WebController extends Controller
{
    
    public function index()
    {
        $galleries = Gallery::orderBy('id','desc')->limit(8)->get();
        $events = Event::where('status',1)->orderBy('id','desc')->limit(3)->get();
        return view('index', compact('galleries','events'));
    }

    public function about()
    {
        return view('about');
    }

    public function contact()
    {
        return view('contact');
    }

    public function saveContact(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required|email',
            'subject' => 'required',
        ]);
        
        UserContact::create([
            'name' => $request->name,
            'email' => $request->email,
            'subject' => $request->subject,
            'message' => $request->message
        ]);

        return redirect()->back()->with('message', 'Thank you we will get back to you shortly');
    }

    public function volunteer()
    {
        $events = Event::where('status',1)->orderBy('id','desc')->limit(3)->get();
        return view('volunteer', compact('events'));
    }

    public function saveVolunteer(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required|email',
            'phone' => 'required|numeric|digits:10',
            'address' => 'required',
        ]);
        
        Volunteer::create([
            'name' => $request->name,
            'email' => $request->email,
            'phone' => $request->phone,
            'address' => $request->address,
            'message' => $request->message
        ]);

        return redirect()->back()->with('message', 'Thank you we will get back to you shortly');
    }

    public function donate()
    {
        return view('donate');
    }

    public function serve()
    {
        return view('feature');
    }
}
